Learn R Programming

radsafer (version 2.4.0)

RN_Spec_Act: Specific Activity

Description

Provides specific activity of a radionuclide in Bq/g.

Usage

RN_Spec_Act(RN_select, numeric = "n")

Value

specific activity in Bq / g

Arguments

RN_select

identify the radionuclide of interest in the format "Es-254m". For multiple specific activities, combine the radionuclides of interest in the form, c("At-219", "Es-251").

numeric

default is "n" and a data frame is returned showing the radionuclide, its relative specific activity, and the units. If "y", or any other option is selected for the numeric parameter, specific activity results are delivered as numeric.

See Also

Other radionuclides: RN_bin_screen_phot(), RN_index_screen(), RN_info(), RN_plot_df(), RN_plot_search_results(), RN_plot_spectrum(), RN_save_spectrum(), RN_search_alpha_by_E(), RN_search_beta_by_E(), RN_search_phot_by_E()

Examples

Run this code
RN_Spec_Act("Ac-230")
RN_Spec_Act(c("At-219", "Es-251"))
RN_Spec_Act("Pd-96", numeric = "y")
RN_Spec_Act(c("Cs-137", "Ba-137m"), numeric = "y")

Run the code above in your browser using DataLab