Learn R Programming

radsafer (version 2.4.0)

RN_find_parent: Find a potential precursor of a radionuclide @description Find a potential parent radionuclide by searching the progeny fields in RadData ICRP_07.NDX

Description

Find a potential precursor of a radionuclide @description Find a potential parent radionuclide by searching the progeny fields in RadData ICRP_07.NDX

Usage

RN_find_parent(RN_select)

Value

a subset of the data frame RadData::ICRP_07.NDX

Arguments

RN_select

identify the radionuclide of interest in the format "Es-254m"

Examples

Run this code
Th_230_df <- RN_find_parent("Th-230")

Tl_208_df <- RN_find_parent("Tl-208")

Run the code above in your browser using DataLab