Learn R Programming

radsafer (version 2.4.0)

RN_index_screen: Screen radionuclide data to find matches to decay mode, half-life, and total emission energy

Description

Provides a set of radionuclides matching screening criteria. This is a limited screening based on average energy per transformation. Consider RN_search_phot_by_E, RN_search_alpha_by_E, and RN_search_beta_by_E for spectroscopic measurement matching.

Usage

RN_index_screen(
  dk_mode = NULL,
  min_half_life_seconds = NULL,
  max_half_life_seconds = NULL,
  min_E_alpha = NULL,
  min_E_electron = NULL,
  min_E_photon = NULL
)

Value

data frame of radionuclide data from the RadData package index data (RadData::ICRP_07.NDX), matching search criteria.

Arguments

dk_mode

default = NULL #' select from: 'A' for Alpha 'B-' for Beta Negative 'B+' for Beta Positive 'EC' for Electron Capture 'IT' for Isomeric Transition 'SF' for Spontaneous Fission

min_half_life_seconds

default = NULL. If half-life is known in units other than seconds, enter with conversion factor, e.g. for 15 minutes, enter min_half_life_seconds = 15 * 60.

max_half_life_seconds

default = NULL. If half-life is known in units other than seconds, enter with conversion factor, e.g. for 30 minutes, enter max_half_life_seconds = 30 * 60.

min_E_alpha

default = NULL. This will be used to screen the index for average alpha energy per decay, including all decay branches.

min_E_electron

default = NULL. This will be used to screen the index for average electron energy per decay, including all decay branches.

min_E_photon

default = NULL. This will be used to screen the index for average photon energy per decay, including all decay branches.

See Also

Other radionuclides: RN_Spec_Act(), RN_bin_screen_phot(), RN_info(), RN_plot_df(), RN_plot_search_results(), RN_plot_spectrum(), RN_save_spectrum(), RN_search_alpha_by_E(), RN_search_beta_by_E(), RN_search_phot_by_E()

Examples

Run this code
RN_index_screen(dk_mode = "SF")
RN_index_screen(dk_mode = "IT", max_half_life_seconds = 433 * 3.15e7)

Run the code above in your browser using DataLab