hvl: half-value layer and tenth-value layer computations
Description
Derive hvl and tvl from radiation values through a material thickness.
Usage
hvl(x, y)
Value
a data frame with the inputs, followed by the computed values for attenuation coefficient (listed as "mu"), half-value layer (hvl), tenth-value layer (tvl), and the homogeneity coefficient (hc) which is the ratio of a half-value layer to the following half-value layer.