Learn R Programming

radsafer (version 2.4.0)

mcnp_cone_angle: MCNP Cone Opening Parameter

Description

MCNP cone surface requires a term, t^2, which is the tangent of the cone angle, in radians, squared. This function takes an input in degrees and provides the parameter needed by MCNP.

Usage

mcnp_cone_angle(d)

Value

tangent of cone angle squared

Arguments

d

The cone angle in degrees.

See Also

Other mcnp tools: mcnp_est_nps(), mcnp_matrix_rotations(), mcnp_mesh_bins(), mcnp_plot_out_spec(), mcnp_scan2plot(), mcnp_scan_save(), mcnp_sdef_erg_hist(), mcnp_sdef_erg_line()

Examples

Run this code
mcnp_cone_angle(45)

Run the code above in your browser using DataLab