neutron_geom_cf: Solid Angle Correction for Neutron Detectors with Point Source
Description
Correction factors are needed when an Neutron Rem Detector (NRD)
aka "Remball" is used in close proximity to a points source. This formula
is per ISO ISO 8529-2-2000 section 6.2. Note, however, that the ISO formula
predicts the response. The formula used here takes the inverse to correct
for the over-response.
Usage
neutron_geom_cf(l, r.d, del = 0.5)
Value
The correction factor for solid angle.
Arguments
l
The distance from the center of the detector to the center of the
source. Units of l and r.d must be consistent.
r.d
The detector radius. Value for typical NRD is 11 cm. An example is
also provided with a Rem 500 detector with a radius of 4.5 cm.
del
The neutron effectiveness factor, default per ISO.
See Also
Other rad measurements:
air_dens_cf(),
disk_to_disk_solid_angle(),
scaler_sim(),
tau_estimate()