Learn R Programming

radsafer (version 2.4.0)

tau_estimate: Estimate tau parameter for ratemeter_sim

Description

If the time constant is not known, but the vendor specifies that the ratemeter will reach some percentage of equilibrium in some number of seconds, use this function to estimate tau.

Usage

tau_estimate(pct_eq, t_eq)

Value

tau, the time constant, in seconds.

Arguments

pct_eq

Percent equilibrium

t_eq

Time, in seconds, to the given percent equilibrium is achieved.

See Also

Other rad measurements: air_dens_cf(), disk_to_disk_solid_angle(), neutron_geom_cf(), scaler_sim()

Examples

Run this code
tau_estimate(pct_eq = 90, t_eq = 22)

Run the code above in your browser using DataLab