Provides specific activity of a radionuclide in Bq/g.
Usage
RN_Spec_Act(RN_select, numeric = "n")
Value
specific activity in Bq / g
Arguments
RN_select
identify the radionuclide of interest in the format "Es-254m". For multiple specific activities, combine the radionuclides of interest in the form, c("At-219", "Es-251").
numeric
default is "n" and a data frame is returned showing the radionuclide, its relative specific activity, and the units. If "y", or any other option is selected for the numeric parameter, specific activity results are delivered as numeric.