RN_find_parent: Find a potential precursor of a radionuclide
@description Find a potential parent radionuclide by searching the progeny fields in RadData ICRP_07.NDX
Description
Find a potential precursor of a radionuclide
@description Find a potential parent radionuclide by searching the progeny fields in RadData ICRP_07.NDX
Usage
RN_find_parent(RN_select)
Value
a subset of the data frame RadData::ICRP_07.NDX
Arguments
RN_select
identify the radionuclide of interest in the format "Es-254m"