Provides a set of radionuclides matching screening criteria. This is a limited screening based on average energy per transformation. Consider RN_search_phot_by_E, RN_search_alpha_by_E, and RN_search_beta_by_E for spectroscopic measurement matching.
RN_index_screen(
dk_mode = NULL,
min_half_life_seconds = NULL,
max_half_life_seconds = NULL,
min_E_alpha = NULL,
min_E_electron = NULL,
min_E_photon = NULL
)data frame of radionuclide data from the RadData package index data (RadData::ICRP_07.NDX), matching search criteria.
default = NULL #' select from: 'A' for Alpha 'B-' for Beta Negative 'B+' for Beta Positive 'EC' for Electron Capture 'IT' for Isomeric Transition 'SF' for Spontaneous Fission
default = NULL. If half-life is known in units other than seconds, enter with conversion factor, e.g. for 15 minutes, enter min_half_life_seconds = 15 * 60.
default = NULL. If half-life is known in units other than seconds, enter with conversion factor, e.g. for 30 minutes, enter max_half_life_seconds = 30 * 60.
default = NULL. This will be used to screen the index for average alpha energy per decay, including all decay branches.
default = NULL. This will be used to screen the index for average electron energy per decay, including all decay branches.
default = NULL. This will be used to screen the index for average photon energy per decay, including all decay branches.
Other radionuclides:
RN_Spec_Act(),
RN_bin_screen_phot(),
RN_info(),
RN_plot_df(),
RN_plot_search_results(),
RN_plot_spectrum(),
RN_save_spectrum(),
RN_search_alpha_by_E(),
RN_search_beta_by_E(),
RN_search_phot_by_E()
RN_index_screen(dk_mode = "SF")
RN_index_screen(dk_mode = "IT", max_half_life_seconds = 433 * 3.15e7)
Run the code above in your browser using DataLab