powered by
MCNP cone surface requires a term, t^2, which is the tangent of the cone angle, in radians, squared. This function takes an input in degrees and provides the parameter needed by MCNP.
mcnp_cone_angle(d)
tangent of cone angle squared
The cone angle in degrees.
Other mcnp tools: mcnp_est_nps(), mcnp_matrix_rotations(), mcnp_mesh_bins(), mcnp_plot_out_spec(), mcnp_scan2plot(), mcnp_scan_save(), mcnp_sdef_erg_hist(), mcnp_sdef_erg_line()
mcnp_est_nps()
mcnp_matrix_rotations()
mcnp_mesh_bins()
mcnp_plot_out_spec()
mcnp_scan2plot()
mcnp_scan_save()
mcnp_sdef_erg_hist()
mcnp_sdef_erg_line()
mcnp_cone_angle(45)
Run the code above in your browser using DataLab